==> node-rollup_2.28.2.orig.tar.gz: rollup-2.28.2/.github/ISSUE_TEMPLATE/BUG.md <==
---
name: 🐞 Bug Report
about: Something went awry and you'd like to tell us about it.

---

<!--
  ⚡️ katchow! We 💛 issues.

  Please - do not - remove this template.
  Please - do not - skip or remove parts of this template.
  Or your issue may be closed.

  👉🏽 Need help or tech support? Please don't open an issue!
  Head to https://gitter.im/rollup/rollup or https://stackoverflow.com/questions/tagged/rollupjs
  
  👉🏽 Is this issue related to an official plugin? Please do not open an issue here, go to the plugins repository instead: https://github.com/rollup/plugins/issues

  ❤️ Rollup? Please consider supporting our collective:
  👉 https://opencollective.com/rollup/donate
-->

- Rollup Version:
- Operating System (or Browser):
- Node Version (if applicable):
- Link to reproduction (IMPORTANT, read below):

<!--
  Issues without minimal reproductions will be closed! Please provide a link to one by:
  1. Using the REPL at https://rollupjs.org/repl/, or
  2. Using the REPL.it reproduction template at https://repl.it/@rollup/rollup-repro
     (allows full use of all rollup options and plugins), or
  3. Provide a minimal repository link (Read https://git.io/fNzHA for instructions).
     These may take more time to triage than the other options.
     
  For some bugs it this may seem like overkill but believe us, very often what seems like a
  "clear issue" is actually specific to some details of your setup. Having a runnable
  reproduction not only "proves" your bug to us but also allows us to spend all our effort
  fixing the bug instead of struggling to understand your issue.
-->


### Expected Behavior


### Actual Behavior


<!--
  Most issues can be expressed or demonstrated through the REPL or a repository.
  However, the situation may arise where some small code snippets also need to
  be provided. In that situation, please add your code below using
  Fenced Code Blocks (https://help.github.com/articles/creating-and-highlighting-code-blocks/)
-->

==> node-rollup_2.38.4.orig.tar.gz: rollup-2.38.4/.github/ISSUE_TEMPLATE/BUG.md <==
---
name: 🐞 Bug Report
about: Something went awry and you'd like to tell us about it.

---

<!--
  ⚡️ katchow! We 💛 issues.

  Please - do not - remove this template.
  Please - do not - skip or remove parts of this template.
  Or your issue may be closed.

  👉🏽 Need help or tech support? Please don't open an issue!
  Head to https://is.gd/rollup_chat or https://stackoverflow.com/questions/tagged/rollupjs
  
  👉🏽 Is this issue related to an official plugin? Please do not open an issue here, go to the plugins repository instead: https://github.com/rollup/plugins/issues

  ❤️ Rollup? Please consider supporting our collective:
  👉 https://opencollective.com/rollup/donate
-->

- Rollup Version:
- Operating System (or Browser):
- Node Version (if applicable):
- Link to reproduction (IMPORTANT, read below):

<!--
  Issues without minimal reproductions will be closed! Please provide a link to one by:
  1. Using the REPL at https://rollupjs.org/repl/, or
  2. Using the REPL.it reproduction template at https://repl.it/@rollup/rollup-repro
     (allows full use of all rollup options and plugins), or
  3. Provide a minimal repository link (Read https://git.io/fNzHA for instructions).
     These may take more time to triage than the other options.
     
  For some bugs it this may seem like overkill but believe us, very often what seems like a
  "clear issue" is actually specific to some details of your setup. Having a runnable
  reproduction not only "proves" your bug to us but also allows us to spend all our effort
  fixing the bug instead of struggling to understand your issue.
-->


### Expected Behavior


### Actual Behavior


<!--
  Most issues can be expressed or demonstrated through the REPL or a repository.
  However, the situation may arise where some small code snippets also need to
  be provided. In that situation, please add your code below using
  Fenced Code Blocks (https://help.github.com/articles/creating-and-highlighting-code-blocks/)
-->
